@@ -13,15 +13,11 @@ class QolsysTablePowerGDevice(QolsysTable):
         self._uri = "content://com.qolsys.qolsysprovider.PowerGDeviceContentProvider/powerg_device"
         self._table = "powerg_device"
         self._abort_on_error = False
+        self._implemented = False
+
 
         self._columns = [
             "_id",
         ]
 
         self._create_table()
-
-    def insert(self, data: dict) -> None:
-        if data is not None:
-            LOGGER.error("Please Report")
-            LOGGER.error("Loading Table Format: %s", self.uri)
-            LOGGER.error(data)
