@@ -219,13 +219,13 @@ class QolsysState(QolsysObservable):
                         # Update Thermostat
                         if isinstance(state_zwave, QolsysThermostat) and isinstance(db_zwave, QolsysThermostat):
                             state_zwave.update_base(db_zwave.to_dict_base())
-                            state_zwave.update_thermostat(db_zwave.to_dict_base())
+                            state_zwave.update_thermostat(db_zwave.to_dict_thermostat)
                             break
 
                         # Update Lock
                         if isinstance(state_zwave, QolsysLock) and isinstance(db_zwave, QolsysLock):
                             state_zwave.update_base(db_zwave.to_dict_base())
-                            state_zwave.update_lock(db_zwave.to_dict_base())
+                            state_zwave.update_lock(db_zwave.to_dict_lock)
                             break
 
                         # Generic Z-Wave Device
@@ -234,8 +234,8 @@ class QolsysState(QolsysObservable):
                             break
 
                         # zwave node_id has changed of node_type, delete and add again
-                        # self.zwave_delete(int(state_zwave.node_id))  # noqa: ERA001
-                        # self.zwave_add(db_zwave)  # noqa: ERA001
+                        # self.zwave_delete(int(state_zwave.node_id))
+                        # self.zwave_add(db_zwave)
 
         # Add new zwave device
         for db_zwave in db_zwaves:
